# Changelog

All notable changes to this project will be documented in this file.

## [1.0.2] - 2024-08-13

### 🐛 Bug Fixes

- Remove sklearn parallel dependency (#196)

### 📚 Documentation

- Update robustness documentation (#194)
- Adding tutorials (#195)

## [1.0.1] - 2024-08-13

### 🚀 Features

- Add metrics for robustness in binary classification (#191)

### ⚙️ Miscellaneous Tasks

- Update Dataset documentation and remove unused dependencies. (#192)
- Update slack message (#193)

## [1.0.0] - 2024-08-01

### 🐛 Bug Fixes

- Outdate tutorials and adding metadata visualization to dataset (#177)
- Split release and publish (#185)

### 📚 Documentation

- Documentation and docstring (#100)

### ⚙️ Miscellaneous Tasks

- Restore correct version (#184)

## [0.7.3] - 2024-01-08

### 🚀 Features

- Adding fairea tool (#88)
- New release (#99)

### 🐛 Bug Fixes

- Explainability ease score and sort feat imp (#97)
- Calibrated equalized odds random state (#98)

## [0.7.2] - 2023-10-25

### 🐛 Bug Fixes

- Alpha importance and overlap (#93)
- Documentation and tutorrials

### ⚙️ Miscellaneous Tasks

- Pre-commit
- Update docs
- Refactoringexplainablity
- Fix little errors
- Update documentation for exaplainability (#94)
- New release (#95)

## [0.7.1] - 2023-10-13

### ⚙️ Miscellaneous Tasks

- Pupdate readthedocs

## [0.7.0] - 2023-10-13

### 🚀 Features

- New feature explainability module (#87)

### 🐛 Bug Fixes

- Removing time processing calculation and print statement (#84)
- Pre-commit documentation
- Build readthedocs

### 🧪 Testing

- Implementing unit tests for correlation plot (#77)

## [0.6.0] - 2023-07-14

### 🚀 Features

- Split build settings -> default (metrics) and extras=methods

### 🐛 Bug Fixes

- Update bug when update sklearn version

### 📚 Documentation

- Update documentation

## [0.5.0] - 2023-06-27

### 🚜 Refactor

- Updating bias measuring tutorials for use with latest package version (#47)

### 📚 Documentation

- Updating documentation for PluginEstimationAndCalibration method (#51)
- Update readthedocs
- Buiild and update generated flels   for reereadthedocs (#57)
- Fix requeriments.txt
- Update requeriiments.txt readthedocs
- Update  readthedocs config
- Update featurers
- Update dependencies
- Fixing pre-commit
- Update new reradthedocs  project
- Update changelog and  tag (#65)

## [0.4.0] - 2023-05-18

### 🚀 Features

- Adding prediction function and update tutorial for Fair Top K C… (#23)

### 🐛 Bug Fixes

- Add mcmf method (#26)
- N_cluster notation (#25)
- Fairlet preprocessing documentation (#24)
- Resolve compatibility with sklearn 1.2.1 (#31)
- Update CHANGELOG.md (#43)
- Remove commitizen (#46)

### 🚜 Refactor

- Reorganizing binary classification tutorials (#35)

### 📚 Documentation

- Add bias mitigation clustering tutorials (#28)
- Moving tutorials (#37)
- Updated_changelog_file (#39)
- Update CHANGELOG.md (#44)

## [0.3.0] - 2023-01-27

### 🚀 Features

- Release new mitigation techniques (#4)

### Bump

- Version 0.2.0 → 0.3.0

## [0.1.4] - 2023-01-26

### 🐛 Bug Fixes

- Test new version

### Bump

- Version 0.1.3 → 0.1.4

## [0.1.2] - 2023-01-26

### 🐛 Bug Fixes

- Add license file
- Add workflows
- Remove unused versions
- Remove unused imports
- Test new version

### 🚜 Refactor

- Second commit
- Remove .idea directory

### Bump

- Version 0.1.1 → 0.1.2

<!-- generated by git-cliff -->
